@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -55,7 +55,7 @@ __all__ = ("CodeStarClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -79,7 +79,7 @@ class Exceptions:
 
 class CodeStarClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html)
     """
 
@@ -97,13 +97,13 @@ class CodeStarClient(BaseClient):
         projectId: str,
         userArn: str,
         projectRole: str,
-        clientRequestToken: str = None,
-        remoteAccessAllowed: bool = None
+        clientRequestToken: str = ...,
+        remoteAccessAllowed: bool = ...
     ) -> AssociateTeamMemberResultTypeDef:
         """
         Adds an IAM user to the team for an AWS CodeStar project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.associate_team_member)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.associate_team_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#associate_team_member)
         """
 
@@ -111,7 +111,7 @@ class CodeStarClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#can_paginate)
         """
 
@@ -120,37 +120,37 @@ class CodeStarClient(BaseClient):
         *,
         name: str,
         id: str,
-        description: str = None,
-        clientRequestToken: str = None,
-        sourceCode: List["CodeTypeDef"] = None,
-        toolchain: "ToolchainTypeDef" = None,
-        tags: Dict[str, str] = None
+        description: str = ...,
+        clientRequestToken: str = ...,
+        sourceCode: Sequence["CodeTypeDef"] = ...,
+        toolchain: "ToolchainTypeDef" = ...,
+        tags: Mapping[str, str] = ...
     ) -> CreateProjectResultTypeDef:
         """
         Creates a project, including project resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.create_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.create_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#create_project)
         """
 
     def create_user_profile(
-        self, *, userArn: str, displayName: str, emailAddress: str, sshPublicKey: str = None
+        self, *, userArn: str, displayName: str, emailAddress: str, sshPublicKey: str = ...
     ) -> CreateUserProfileResultTypeDef:
         """
         Creates a profile for a user that includes user preferences, such as the display
         name and email address assocciated with the user, in AWS CodeStar.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.create_user_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.create_user_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#create_user_profile)
         """
 
     def delete_project(
-        self, *, id: str, clientRequestToken: str = None, deleteStack: bool = None
+        self, *, id: str, clientRequestToken: str = ..., deleteStack: bool = ...
     ) -> DeleteProjectResultTypeDef:
         """
         Deletes a project, including project resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.delete_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.delete_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#delete_project)
         """
 
@@ -159,7 +159,7 @@ class CodeStarClient(BaseClient):
         Deletes a user profile in AWS CodeStar, including all personal preference data
         associated with that profile, such as display name and email address.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.delete_user_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.delete_user_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#delete_user_profile)
         """
 
@@ -167,7 +167,7 @@ class CodeStarClient(BaseClient):
         """
         Describes a project and its resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.describe_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.describe_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#describe_project)
         """
 
@@ -175,7 +175,7 @@ class CodeStarClient(BaseClient):
         """
         Describes a user in AWS CodeStar and the user attributes across all projects.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.describe_user_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.describe_user_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#describe_user_profile)
         """
 
@@ -183,97 +183,95 @@ class CodeStarClient(BaseClient):
         """
         Removes a user from a project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.disassociate_team_member)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.disassociate_team_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#disassociate_team_member)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#generate_presigned_url)
         """
 
     def list_projects(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListProjectsResultTypeDef:
         """
         Lists all projects in AWS CodeStar associated with your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.list_projects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.list_projects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#list_projects)
         """
 
     def list_resources(
-        self, *, projectId: str, nextToken: str = None, maxResults: int = None
+        self, *, projectId: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListResourcesResultTypeDef:
         """
         Lists resources associated with a project in AWS CodeStar.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.list_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.list_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#list_resources)
         """
 
     def list_tags_for_project(
-        self, *, id: str, nextToken: str = None, maxResults: int = None
+        self, *, id: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListTagsForProjectResultTypeDef:
         """
         Gets the tags for a project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.list_tags_for_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.list_tags_for_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#list_tags_for_project)
         """
 
     def list_team_members(
-        self, *, projectId: str, nextToken: str = None, maxResults: int = None
+        self, *, projectId: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListTeamMembersResultTypeDef:
         """
         Lists all team members associated with a project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.list_team_members)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.list_team_members)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#list_team_members)
         """
 
     def list_user_profiles(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListUserProfilesResultTypeDef:
         """
         Lists all the user profiles configured for your AWS account in AWS CodeStar.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.list_user_profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.list_user_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#list_user_profiles)
         """
 
-    def tag_project(self, *, id: str, tags: Dict[str, str]) -> TagProjectResultTypeDef:
+    def tag_project(self, *, id: str, tags: Mapping[str, str]) -> TagProjectResultTypeDef:
         """
         Adds tags to a project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.tag_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.tag_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#tag_project)
         """
 
-    def untag_project(self, *, id: str, tags: List[str]) -> Dict[str, Any]:
+    def untag_project(self, *, id: str, tags: Sequence[str]) -> Dict[str, Any]:
         """
         Removes tags from a project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.untag_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.untag_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#untag_project)
         """
 
-    def update_project(
-        self, *, id: str, name: str = None, description: str = None
-    ) -> Dict[str, Any]:
+    def update_project(self, *, id: str, name: str = ..., description: str = ...) -> Dict[str, Any]:
         """
         Updates a project in AWS CodeStar.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.update_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.update_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#update_project)
         """
 
@@ -282,13 +280,13 @@ class CodeStarClient(BaseClient):
         *,
         projectId: str,
         userArn: str,
-        projectRole: str = None,
-        remoteAccessAllowed: bool = None
+        projectRole: str = ...,
+        remoteAccessAllowed: bool = ...
     ) -> UpdateTeamMemberResultTypeDef:
         """
         Updates a team member's attributes in an AWS CodeStar project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.update_team_member)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.update_team_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#update_team_member)
         """
 
@@ -296,28 +294,28 @@ class CodeStarClient(BaseClient):
         self,
         *,
         userArn: str,
-        displayName: str = None,
-        emailAddress: str = None,
-        sshPublicKey: str = None
+        displayName: str = ...,
+        emailAddress: str = ...,
+        sshPublicKey: str = ...
     ) -> UpdateUserProfileResultTypeDef:
         """
         Updates a user's profile in AWS CodeStar.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Client.update_user_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Client.update_user_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/client.html#update_user_profile)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Paginator.ListProjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Paginator.ListProjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/paginators.html#listprojectspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_resources"]) -> ListResourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Paginator.ListResources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Paginator.ListResources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/paginators.html#listresourcespaginator)
         """
 
@@ -326,7 +324,7 @@ class CodeStarClient(BaseClient):
         self, operation_name: Literal["list_team_members"]
     ) -> ListTeamMembersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Paginator.ListTeamMembers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Paginator.ListTeamMembers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/paginators.html#listteammemberspaginator)
         """
 
@@ -335,6 +333,6 @@ class CodeStarClient(BaseClient):
         self, operation_name: Literal["list_user_profiles"]
     ) -> ListUserProfilesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.23/reference/services/codestar.html#CodeStar.Paginator.ListUserProfiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codestar.html#CodeStar.Paginator.ListUserProfiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar/paginators.html#listuserprofilespaginator)
         """
